==> filemv0.52.5.zip: source/batch.cpp <==
#include "defextern.h"


#ifndef STRICT
    #define STRICT
#endif
#include <stdio.h>
#include <fstream.h>
#include <windows.h>
#include <wininet.h>
#include <windowsx.h>
#include <commctrl.h>
#include "resource.h"
#include "myfilemv.h"
#include "initial.h"
#include "file.h"
#include "batch.h"
#include "main.h"
#include "status.h"

char batchExt[]= "tfa";


struct status
{
	BOOL connect;//C^[lbgɐڑĂ邩ǂ
	char host[1];
	void init() {connect=FALSE;strcpy(host,""); };
	void sethost(char *h) {strcpy(host,h);};
	BOOL checkhost(char *h) {return (strcmp(h,host)==0); };
} ;

status sta;

void editbatch(char *file)
{
	ShellExecute(NULL,  "open",editor ,file, NULL, SW_SHOW);
}


void setautoendcomment(char *file, char *buff,int success,int fail,int fnum,int allnum)
{
	wsprintf(buff,":I [%s] ڑ :%d ~:%d (%d/%d)",file,success,fail,fnum,allnum);
	setstatus(buff);
}


// Abv[ht@CǂAgq`FbN

BOOL checkbatch(char *file)
{
	return checkExt(file,batchExt);
}

// Abv[ht@CAgX[hύXǂ
// ascii, binary

BOOL checktransmode(char *buf)
{
	BOOL ans=FALSE;
	return ans;
}


void batch(char *file)
{
	int upnum=0;
	int allnum=0;
	if( checkbatch(file)==FALSE ) 
	{
		setstatusonly("gqtfał͂܂");
		return;
	}
	AddAutofile(file);
	char buf[MAX_PATH*4];
	char filefrom[MAX_PATH];
	char fileto[MAX_PATH];
	char* to;
	ifstream in(file, ios::nocreate);
	if(!in) return;
	setstatusonly("Jn");
	int success=0;
	int fail=0;
	while(!in.eof())
	{
		in.getline(buf,MAX_PATH*4);
		if(strncmp(buf,"quit",4)==0) break; // quit ŏI
		if(checktransmode(buf)) continue;
		if( !ishost(buf)) continue;
		//myftpaddress.setname(buf);
		//@ڑł+1
		if(sta.connect==FALSE) 
		{
			fail++;
			continue;
		}
		else success++;
		setstatusonly(buf);
		resettitle();
		while(!in.eof())
		{
			in.getline(buf,MAX_PATH*4);
			if(checktransmode(buf)) continue;
			if(strcmp(buf,"end")==0) break;
			strcpy(filefrom,buf);
			in.getline(fileto,MAX_PATH);
			if(strcmp(fileto,"end")==0) break;
			SetCurrentDirectory(filefrom);
			to=strrchr(filefrom,'\\');
			if(to==NULL) to=strrchr(filefrom,'/');
			if(to==NULL) to=filefrom;
			else to++;
			allnum++;
		}
	}
	resettitle();
}

==> filemv0.342.0.1.zip: source/batch.cpp <==
#include "defextern.h"


#ifndef STRICT
    #define STRICT
#endif
#include <stdio.h>
#include <fstream.h>
#include <windows.h>
#include <wininet.h>
#include <windowsx.h>
#include <commctrl.h>
#include "resource.h"
#include "myfilemv.h"
#include "initial.h"
#include "file.h"
#include "batch.h"
#include "main.h"
#include "status.h"

char batchExt[]= "tfa";

void editbatch(char *file)
{
	ShellExecute(NULL,  "open",editor ,file, NULL, SW_SHOW);
}


void setautoendcomment(char *file, char *buff,int success,int fail,int fnum,int allnum)
{
	wsprintf(buff,":I [%s] ڑ :%d ~:%d (%d/%d)",file,success,fail,fnum,allnum);
	setstatus(buff);
}


// Abv[ht@CǂAgq`FbN

BOOL checkbatch(char *file)
{
	return checkExt(file,batchExt);
}

// Abv[ht@CAgX[hύXǂ
// ascii, binary

BOOL checktransmode(char *buf)
{
	BOOL ans=FALSE;
	if(strcmp(buf,"ascii")==0)
	{
		settransfermode(ASCII);
		ans=TRUE;
	}
	if(strcmp(buf,"binary")==0)
	{
		settransfermode(BINARY);
		ans=TRUE;
	}
	return ans;
}


void batch(char *file)
{
	int upnum=0;
	int allnum=0;
	if( checkbatch(file)==FALSE ) 
	{
		setstatusonly("gqtfał͂܂");
		return;
	}
	AddAutofile(file);
	char buf[MAX_PATH*4];
	char filefrom[MAX_PATH];
	char fileto[MAX_PATH];
	char* to;
	ifstream in(file, ios::nocreate);
	if(!in) return;
	setstatusonly("Jn");
	settransfermode(ASCII);
	int success=0;
	int fail=0;
	while(!in.eof())
	{
		in.getline(buf,MAX_PATH*4);
		if(strncmp(buf,"quit",4)==0) break; // quit ŏI
		if(checktransmode(buf)) continue;
		if( !ishost(buf)) continue;
		myftpaddress.setname(buf);
		//@ڑł+1
		if(st.connect==FALSE) 
		{
			fail++;
			continue;
		}
		else success++;
		setstatusonly(buf);
		resettitle();
		while(!in.eof())
		{
			in.getline(buf,MAX_PATH*4);
			if(checktransmode(buf)) continue;
			if(strcmp(buf,"end")==0) break;
			strcpy(filefrom,buf);
			in.getline(fileto,MAX_PATH);
			if(strcmp(fileto,"end")==0) break;
			SetCurrentDirectory(filefrom);
			to=strrchr(filefrom,'\\');
			if(to==NULL) to=strrchr(filefrom,'/');
			if(to==NULL) to=filefrom;
			else to++;
			allnum++;
		}
	}
	resettitle();
}
